JoystickValue class final

Normalized two-axis joystick value in the -1..1 range.

Constructors

JoystickValue(double x, double y)
Creates a joystick value.
const

Properties

hashCode int
The hash code for this object.
no setteroverride
magnitude double
Distance from the center in the 0..1 range.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
x double
Horizontal axis, where left is -1 and right is 1.
final
y double
Vertical axis, where up is -1 and down is 1.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

zero → const JoystickValue
Centered joystick value.