VirtualJoystick class

Reusable two-axis joystick built entirely with Flutter widgets and painting.

The joystick does not know what it controls. Consumers listen to controller and apply its normalized value to a camera, character, vehicle, or any other interactive object.

Inheritance

Constructors

VirtualJoystick({Key? key, required VirtualJoystickController controller, double size = 116, double deadZone = 0.08, Color baseColor = const Color(0xbb071527), Color accentColor = const Color(0xff7dd3fc)})
Creates a virtual joystick.
const

Properties

accentColor Color
Active thumb and direction color.
final
baseColor Color
Background and border color basis.
final
controller VirtualJoystickController
Receives normalized joystick values.
final
deadZone double
Center area that produces a zero value.
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size double
Square joystick size.
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<VirtualJoystick>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited