BoxShape class final

An axis-aligned box collider described by half-extents.

For a two-meter-wide box, use halfWidth: 1.

Inheritance

Constructors

BoxShape({required double halfWidth, required double halfHeight, required double halfDepth})
Creates a box collider from its positive half-extents.
const

Properties

halfDepth double
Half of the total depth along the Z axis.
final
halfHeight double
Half of the total height along the Y axis.
final
halfWidth double
Half of the total width along the X axis.
final
hashCode int
The hash code for this object.
no setterinherited
nativeA double
First native shape parameter.
no setteroverride
nativeB double
Second native shape parameter.
no setteroverride
nativeC double
Third native shape parameter.
no setteroverride
nativeType int
Internal identifier passed to the native Jolt adapter.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited