ColliderShape class sealed

Base class for collision geometry attached to a rigid body.

A collider shape is invisible. A renderer may display any visual model while Jolt uses the shape to calculate contacts, movement, and impulses.

Implementers

Properties

hashCode int
The hash code for this object.
no setterinherited
nativeA double
First native shape parameter.
no setter
nativeB double
Second native shape parameter.
no setter
nativeC double
Third native shape parameter.
no setter
nativeType int
Internal identifier passed to the native Jolt adapter.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited