CylinderShape class final

A cylinder collider aligned with the Y axis.

Prefer a capsule when rounded edges are acceptable. Cylinders can be less stable around sharp edges during dynamic simulation.

Inheritance

Constructors

CylinderShape({required double halfHeight, required double radius})
Creates a cylinder from its positive halfHeight and radius.
const

Properties

halfHeight double
Half of the cylinder height along the Y axis.
final
hashCode int
The hash code for this object.
no setterinherited
nativeA double
First native shape parameter.
no setteroverride
nativeB double
Second native shape parameter.
no setteroverride
nativeC double
Third native shape parameter.
no setteroverride
nativeType int
Internal identifier passed to the native Jolt adapter.
no setteroverride
radius double
Radius of the circular caps.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited