SphereShape class final

A spherical collider.

Spheres are useful for balls, projectiles, and inexpensive trigger volumes.

Inheritance

Constructors

SphereShape({required double radius})
Creates a sphere with the supplied positive radius.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
nativeA double
First native shape parameter.
no setteroverride
nativeB double
Second native shape parameter.
no setteroverride
nativeC double
Third native shape parameter.
no setteroverride
nativeType int
Internal identifier passed to the native Jolt adapter.
no setteroverride
radius double
Radius of the sphere.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited