BodyId class final

Stable identifier for a native Jolt body inside one physics world.

Do not reuse a BodyId after destroying its RigidBody.

Constructors

BodyId(int value)
Creates an identifier from the native Jolt body handle.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int
Native body index and sequence number encoded by Jolt.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited