RenderLight class final

Renderer handle paired with the immutable settings used to create it.

Constructors

RenderLight({required LightId id, required Light settings})
Creates a render light handle.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
id LightId
Identifier used for renderer operations.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
settings Light
Initial renderer settings.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited