RenderModelAsset class final

Loaded visual model asset owned by a renderer.

Constructors

RenderModelAsset({required ModelAssetId id, required ModelAsset settings})
Creates a loaded asset handle.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
id ModelAssetId
Identifier used for renderer operations.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
settings ModelAsset
Immutable source settings.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited