RenderModelInstance class final

One visible occurrence of a loaded RenderModelAsset.

A single room or furniture asset can have many instances with independent transforms.

Constructors

RenderModelInstance({required ModelInstanceId id, required RenderModelAsset asset, required PhysicsTransform transform, ModelAnimationPlayback? animation})
Creates a visible instance handle.

Properties

animation ModelAnimationPlayback?
Latest requested animation playback, or null when stopped.
getter/setter pair
asset RenderModelAsset
Shared loaded asset used by this instance.
final
hashCode int
The hash code for this object.
no setterinherited
id ModelInstanceId
Identifier used for renderer operations.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
transform PhysicsTransform
Latest world-space transform.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited