AmbientOcclusionOptions class final

Constructors

AmbientOcclusionOptions({bool enabled = false, double radius = 0.3, double intensity = 1, double power = 1, RenderQuality quality = RenderQuality.low})
const

Properties

enabled bool
final
hashCode int
The hash code for this object.
no setterinherited
intensity double
final
power double
final
quality RenderQuality
final
radius double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMessage() Map<String, Object>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited