BloomOptions class final

Constructors

BloomOptions({bool enabled = false, double strength = 0.1, int resolution = 384, int levels = 6, bool threshold = true, RenderQuality quality = RenderQuality.low})
const

Properties

enabled bool
final
hashCode int
The hash code for this object.
no setterinherited
levels int
final
quality RenderQuality
final
resolution int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
strength double
final
threshold bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMessage() Map<String, Object>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited