ScreenSpaceReflectionsOptions class final

Constructors

ScreenSpaceReflectionsOptions({bool enabled = false, double thickness = 0.1, double bias = 0.01, double maxDistance = 3, double stride = 2})
const

Properties

bias double
final
enabled bool
final
hashCode int
The hash code for this object.
no setterinherited
maxDistance double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stride double
final
thickness double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMessage() Map<String, Object>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited