CapsuleShape class final
A capsule collider aligned with the Y axis.
Capsules are commonly used for characters and animals because they slide smoothly over edges and are more stable than detailed mesh colliders.
- Inheritance
-
- Object
- ColliderShape
- CapsuleShape
Constructors
- CapsuleShape({required double halfHeight, required double radius})
-
Creates a capsule with a cylindrical half-height and rounded caps.
const
Properties
- halfHeight → double
-
Half of the cylindrical segment height, excluding the rounded caps.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- nativeA → double
-
First native shape parameter.
no setteroverride
- nativeB → double
-
Second native shape parameter.
no setteroverride
- nativeC → double
-
Third native shape parameter.
no setteroverride
- nativeType → int
-
Internal identifier passed to the native Jolt adapter.
no setteroverride
- radius → double
-
Radius of the cylindrical segment and both caps.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited