Ray class final
A finite world-space ray used for physics queries.
Constructors
Properties
- direction → Vector3
-
Direction toward the queried objects.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxDistance → double
-
Maximum query distance in world units.
final
- normalizedDirection → Vector3
-
Unit-length direction used by the native adapter.
no setter
- origin → Vector3
-
Starting point in world coordinates.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
pointAtFraction(
double fraction) → Vector3 -
Returns the world-space point at
fractionalong this ray. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited