RigidBodySettings class final
Describes a rigid body before it is inserted into a PhysicsWorld.
Constructors
- RigidBodySettings({required ColliderShape shape, required MotionType motionType, required PhysicsTransform transform, Vector3 linearVelocity = Vector3.zero, Vector3 angularVelocity = Vector3.zero, double friction = 0.5, double restitution = 0, bool isSensor = false})
-
Creates immutable body settings.
const
Properties
- angularVelocity → Vector3
-
Initial rotation speed in radians per second.
final
- friction → double
-
Surface friction coefficient.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isSensor → bool
-
Whether the body reports overlaps without producing collision response.
final
- linearVelocity → Vector3
-
Initial movement in world units per second.
final
- motionType → MotionType
-
Determines whether the body is static, kinematic, or dynamic.
final
- restitution → double
-
Surface bounciness coefficient.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shape → ColliderShape
-
Invisible collision geometry used by Jolt.
final
- transform → PhysicsTransform
-
Initial world-space position and orientation.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited