RenderLight class final
Renderer handle paired with the immutable settings used to create it.
Constructors
- RenderLight({required LightId id, required Light settings})
-
Creates a render light handle.
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited