ModelAnimation class final
One animation clip embedded in an animated model asset.
Constructors
- ModelAnimation({required int index, required String name, required double durationSeconds})
-
Creates animation metadata returned by Filament.
const
-
ModelAnimation.fromMessage(Map<
Object?, Object?> message) -
Creates metadata from a native renderer message.
factory
Properties
- durationSeconds → double
-
Clip duration in seconds.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
Zero-based clip index used by Filament Animator.
final
- name → String
-
Clip name embedded in the GLB file.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited