RenderOptions class final
Scene render quality and post-processing options.
These settings describe how a backend renders the active view. Backends can ignore unsupported knobs while preserving the same Dart API.
Constructors
- RenderOptions({bool postProcessing = true, bool shadows = true, ShadowType shadowType = ShadowType.pcf, AmbientOcclusionOptions ambientOcclusion = const AmbientOcclusionOptions(), BloomOptions bloom = const BloomOptions(), ScreenSpaceReflectionsOptions screenSpaceReflections = const ScreenSpaceReflectionsOptions(), MsaaOptions msaa = const MsaaOptions()})
-
const
Properties
- ambientOcclusion → AmbientOcclusionOptions
-
final
- bloom → BloomOptions
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- msaa → MsaaOptions
-
final
- postProcessing → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- screenSpaceReflections → ScreenSpaceReflectionsOptions
-
final
- shadows → bool
-
final
- shadowType → ShadowType
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMessage(
) → Map< String, Object> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited